"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var markdown_view_common_1 = require("./markdown-view.common");
var style_properties_1 = require("@nativescript/core/ui/styling/style-properties");
var color_1 = require("@nativescript/core/color/color");
var MarkdownView = (function (_super) {
    __extends(MarkdownView, _super);
    function MarkdownView() {
        var _this = _super.call(this) || this;
        _this.mdParser = TSMarkdownParser.standardParser();
        return _this;
    }
    MarkdownView.prototype.createNativeView = function () {
        this._ios = _super.prototype.createNativeView.call(this);
        this._ios.editable = false;
        this._ios.selectable = true;
        this._ios.scrollEnabled = false;
        return this._ios;
    };
    MarkdownView.prototype[style_properties_1.fontSizeProperty.setNative] = function (fontSize) {
        this._fontSize = fontSize;
        this._updateStyling();
    };
    MarkdownView.prototype[style_properties_1.colorProperty.setNative] = function (value) {
        this._color = value instanceof color_1.Color ? value.ios : value;
        this._updateStyling();
    };
    MarkdownView.prototype[markdown_view_common_1.markdownProperty.setNative] = function (markdown) {
        this._currentMarkdown = markdown;
        this._updateMarkdown();
    };
    MarkdownView.prototype._updateMarkdown = function () {
        if (this._currentMarkdown) {
            this._ios.attributedText = this.mdParser.attributedStringFromMarkdown(this._currentMarkdown);
        }
        else {
            this._ios.text = '';
        }
    };
    MarkdownView.prototype._updateStyling = function () {
        var defaultAttributes = NSDictionary.dictionaryWithObjectsForKeys([
            UIFont.systemFontOfSize(this._fontSize),
            this._color
        ], [
            NSFontAttributeName,
            NSForegroundColorAttributeName
        ]);
        var emphasisAttributes = NSDictionary.dictionaryWithObjectsForKeys([UIFont.italicSystemFontOfSize(this._fontSize)], [NSFontAttributeName]);
        var strongAttributes = NSDictionary.dictionaryWithObjectsForKeys([UIFont.boldSystemFontOfSize(this._fontSize)], [NSFontAttributeName]);
        this.mdParser.defaultAttributes = defaultAttributes;
        this.mdParser.emphasisAttributes = emphasisAttributes;
        this.mdParser.strongAttributes = strongAttributes;
        this._updateMarkdown();
    };
    return MarkdownView;
}(markdown_view_common_1.MarkdownViewBase));
exports.MarkdownView = MarkdownView;
//# sourceMappingURL=markdown-view.ios.js.map